@@ -1,14 +1,14 @@
 /**
  * Author: Wolfgang Kühn 2020
- * Source located at https://github.com/decatur/app-chen
+ * Source located at https://github.com/decatur/appchen
  *
  * Module implementing a web component which represents a transactional time interval.
  * It subscribes to the 'time_state' and 'time_changed' events to synchronize UI-time with server time.
  * This web component may serve as a template for your own web components.
  */
 import {disableButtons, enableButtons, busy} from "./formen.js"
-import * as io from "/appchen/web_client/io.js"
-import {toLocaleISODateTimeString, resolvePeriod} from "/gridchen/utils.js";
+import * as io from "appchen/web_client/io.js"
+import {toLocaleISODateTimeString, resolvePeriod} from "gridchen/utils.js";
 
 const html = `<form style="margin-top:1ex">
     <fieldset>
@@ -64,7 +64,7 @@ class TimeInterval extends HTMLElement {
             end.value = toLocaleISODateTimeString(endTransactionTime, resolvePeriod('SECONDS'));
         }
 
-        io.stream().subscribe({
+        io.stream('').subscribe({
             'time_state': processTime,
             'time_changed': (response) => {
                 if (toggleLock.textContent === '🔓') return;
