@@ -1,8 +1,8 @@
 // This is a Weblet module.
 
-import "/appchen/web_client/grid-chen/webcomponent.js";
-import {createView} from "/gridchen/matrixview.js"
-import * as io from "/appchen/web_client/io.js";
+import "gridchen/webcomponent.js";
+import {createView} from "gridchen/matrixview.js"
+import * as io from "appchen/web_client/io.js";
 
 const innerHTML = `
 <label>Subscription Active <input class="subscribed" type="checkbox" checked></label>
@@ -83,7 +83,7 @@ export function init(weblet, container) {
     summaryTable.resetFromView(createView(summarySchema, [lastPrice, vwap, transactionCount]));
     transactionsTable = container.querySelector('.transactionsTable');
 
-    const subscription = io.stream().subscribe({
+    const subscription = io.stream('').subscribe({
         'trade_executions_state': (state) => {
             transactionsTable.resetFromView(createView(state.schema, model.transactions));
             model.addTrades(state.data);
